@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2009 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2009 Volker Krause <vkrause@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "dynamicpage.h"
@@ -32,7 +19,7 @@
 DynamicPage::DynamicPage(const QString &uiFile, KAssistantDialog *parent)
     : Page(parent)
 {
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
 
     QWidget *pageParent = this;
@@ -45,7 +32,7 @@ DynamicPage::DynamicPage(const QString &uiFile, KAssistantDialog *parent)
         m_dynamicWidget = loader.load(&file, pageParent);
         file.close();
         if (!Global::poFileName().isEmpty()) {
-            KLocalizedTranslator *translator = new KLocalizedTranslator(this);
+            auto *translator = new KLocalizedTranslator(this);
             QCoreApplication::instance()->installTranslator(translator);
             translator->setTranslationDomain(Global::poFileName());
 
